# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.3.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.


import collections

from sys import version_info as _version_info
if _version_info < (3, 7, 0):
    raise RuntimeError("Python 3.7 or later required")

from . import _ITKCommonPython


from . import _ITKMeshPython



from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _itkConnectedRegionsMeshFilterPython
else:
    import _itkConnectedRegionsMeshFilterPython

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


if _swig_python_version_info[0:2] >= (3, 3):
    import collections.abc
else:
    import collections

import itk.ITKCommonBasePython
import itk.itkMatrixPython
import itk.itkPointPython
import itk.vnl_vectorPython
import itk.vnl_matrixPython
import itk.stdcomplexPython
import itk.pyBasePython
import itk.itkFixedArrayPython
import itk.vnl_vector_refPython
import itk.itkVectorPython
import itk.vnl_matrix_fixedPython
import itk.itkCovariantVectorPython
import itk.itkMeshToMeshFilterPython
import itk.itkMeshBasePython
import itk.itkVectorContainerPython
import itk.itkContinuousIndexPython
import itk.itkIndexPython
import itk.itkSizePython
import itk.itkOffsetPython
import itk.itkArrayPython
import itk.itkMapContainerPython
import itk.itkBoundingBoxPython
import itk.itkPointSetPython
import itk.itkMeshSourcePython

def itkConnectedRegionsMeshFilterMF2MF2_New():
    return itkConnectedRegionsMeshFilterMF2MF2.New()

class itkConnectedRegionsMeshFilterMF2MF2(itk.itkMeshToMeshFilterPython.itkMeshToMeshFilterMF2MF2):
    r"""Proxy of C++ itkConnectedRegionsMeshFilterMF2MF2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkConnectedRegionsMeshFilterMF2MF2_Pointer"""
        return _itkConnectedRegionsMeshFilterPython.itkConnectedRegionsMeshFilterMF2MF2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkConnectedRegionsMeshFilterMF2MF2_Pointer"""
        return _itkConnectedRegionsMeshFilterPython.itkConnectedRegionsMeshFilterMF2MF2_Clone(self)
    PointSeededRegions = _itkConnectedRegionsMeshFilterPython.itkConnectedRegionsMeshFilterMF2MF2_PointSeededRegions
    
    CellSeededRegions = _itkConnectedRegionsMeshFilterPython.itkConnectedRegionsMeshFilterMF2MF2_CellSeededRegions
    
    SpecifiedRegions = _itkConnectedRegionsMeshFilterPython.itkConnectedRegionsMeshFilterMF2MF2_SpecifiedRegions
    
    LargestRegion = _itkConnectedRegionsMeshFilterPython.itkConnectedRegionsMeshFilterMF2MF2_LargestRegion
    
    AllRegions = _itkConnectedRegionsMeshFilterPython.itkConnectedRegionsMeshFilterMF2MF2_AllRegions
    
    ClosestPointRegion = _itkConnectedRegionsMeshFilterPython.itkConnectedRegionsMeshFilterMF2MF2_ClosestPointRegion
    

    def SetExtractionMode(self, _arg):
        r"""
        SetExtractionMode(self, _arg)

        Parameters
        ----------
        _arg: int

        """
        return _itkConnectedRegionsMeshFilterPython.itkConnectedRegionsMeshFilterMF2MF2_SetExtractionMode(self, _arg)

    def GetExtractionMode(self):
        r"""GetExtractionMode(self) -> int"""
        return _itkConnectedRegionsMeshFilterPython.itkConnectedRegionsMeshFilterMF2MF2_GetExtractionMode(self)

    def SetExtractionModeToPointSeededRegions(self):
        r"""SetExtractionModeToPointSeededRegions(self)"""
        return _itkConnectedRegionsMeshFilterPython.itkConnectedRegionsMeshFilterMF2MF2_SetExtractionModeToPointSeededRegions(self)

    def SetExtractionModeToCellSeededRegions(self):
        r"""SetExtractionModeToCellSeededRegions(self)"""
        return _itkConnectedRegionsMeshFilterPython.itkConnectedRegionsMeshFilterMF2MF2_SetExtractionModeToCellSeededRegions(self)

    def SetExtractionModeToSpecifiedRegions(self):
        r"""SetExtractionModeToSpecifiedRegions(self)"""
        return _itkConnectedRegionsMeshFilterPython.itkConnectedRegionsMeshFilterMF2MF2_SetExtractionModeToSpecifiedRegions(self)

    def SetExtractionModeToLargestRegion(self):
        r"""SetExtractionModeToLargestRegion(self)"""
        return _itkConnectedRegionsMeshFilterPython.itkConnectedRegionsMeshFilterMF2MF2_SetExtractionModeToLargestRegion(self)

    def SetExtractionModeToAllRegions(self):
        r"""SetExtractionModeToAllRegions(self)"""
        return _itkConnectedRegionsMeshFilterPython.itkConnectedRegionsMeshFilterMF2MF2_SetExtractionModeToAllRegions(self)

    def SetExtractionModeToClosestPointRegion(self):
        r"""SetExtractionModeToClosestPointRegion(self)"""
        return _itkConnectedRegionsMeshFilterPython.itkConnectedRegionsMeshFilterMF2MF2_SetExtractionModeToClosestPointRegion(self)

    def InitializeSeedList(self):
        r"""InitializeSeedList(self)"""
        return _itkConnectedRegionsMeshFilterPython.itkConnectedRegionsMeshFilterMF2MF2_InitializeSeedList(self)

    def AddSeed(self, id):
        r"""
        AddSeed(self, id)

        Parameters
        ----------
        id: unsigned long

        """
        return _itkConnectedRegionsMeshFilterPython.itkConnectedRegionsMeshFilterMF2MF2_AddSeed(self, id)

    def DeleteSeed(self, id):
        r"""
        DeleteSeed(self, id)

        Parameters
        ----------
        id: unsigned long

        """
        return _itkConnectedRegionsMeshFilterPython.itkConnectedRegionsMeshFilterMF2MF2_DeleteSeed(self, id)

    def InitializeSpecifiedRegionList(self):
        r"""InitializeSpecifiedRegionList(self)"""
        return _itkConnectedRegionsMeshFilterPython.itkConnectedRegionsMeshFilterMF2MF2_InitializeSpecifiedRegionList(self)

    def AddSpecifiedRegion(self, id):
        r"""
        AddSpecifiedRegion(self, id)

        Parameters
        ----------
        id: unsigned long

        """
        return _itkConnectedRegionsMeshFilterPython.itkConnectedRegionsMeshFilterMF2MF2_AddSpecifiedRegion(self, id)

    def DeleteSpecifiedRegion(self, id):
        r"""
        DeleteSpecifiedRegion(self, id)

        Parameters
        ----------
        id: unsigned long

        """
        return _itkConnectedRegionsMeshFilterPython.itkConnectedRegionsMeshFilterMF2MF2_DeleteSpecifiedRegion(self, id)

    def SetClosestPoint(self, p):
        r"""
        SetClosestPoint(self, p)

        Parameters
        ----------
        p: itkPointF2 &

        """
        return _itkConnectedRegionsMeshFilterPython.itkConnectedRegionsMeshFilterMF2MF2_SetClosestPoint(self, p)

    def GetClosestPoint(self, arg0):
        r"""
        GetClosestPoint(self, arg0) -> itkPointF2

        Parameters
        ----------
        arg0: itkPointF2 &

        """
        return _itkConnectedRegionsMeshFilterPython.itkConnectedRegionsMeshFilterMF2MF2_GetClosestPoint(self, arg0)

    def GetNumberOfExtractedRegions(self):
        r"""GetNumberOfExtractedRegions(self) -> unsigned long"""
        return _itkConnectedRegionsMeshFilterPython.itkConnectedRegionsMeshFilterMF2MF2_GetNumberOfExtractedRegions(self)
    __swig_destroy__ = _itkConnectedRegionsMeshFilterPython.delete_itkConnectedRegionsMeshFilterMF2MF2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkConnectedRegionsMeshFilterMF2MF2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkConnectedRegionsMeshFilterPython.itkConnectedRegionsMeshFilterMF2MF2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkConnectedRegionsMeshFilterMF2MF2

        Create a new object of the class itkConnectedRegionsMeshFilterMF2MF2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkConnectedRegionsMeshFilterMF2MF2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkConnectedRegionsMeshFilterMF2MF2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkConnectedRegionsMeshFilterMF2MF2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkConnectedRegionsMeshFilterMF2MF2 in _itkConnectedRegionsMeshFilterPython:
_itkConnectedRegionsMeshFilterPython.itkConnectedRegionsMeshFilterMF2MF2_swigregister(itkConnectedRegionsMeshFilterMF2MF2)

def itkConnectedRegionsMeshFilterMF3MF3_New():
    return itkConnectedRegionsMeshFilterMF3MF3.New()

class itkConnectedRegionsMeshFilterMF3MF3(itk.itkMeshToMeshFilterPython.itkMeshToMeshFilterMF3MF3):
    r"""Proxy of C++ itkConnectedRegionsMeshFilterMF3MF3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkConnectedRegionsMeshFilterMF3MF3_Pointer"""
        return _itkConnectedRegionsMeshFilterPython.itkConnectedRegionsMeshFilterMF3MF3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkConnectedRegionsMeshFilterMF3MF3_Pointer"""
        return _itkConnectedRegionsMeshFilterPython.itkConnectedRegionsMeshFilterMF3MF3_Clone(self)
    PointSeededRegions = _itkConnectedRegionsMeshFilterPython.itkConnectedRegionsMeshFilterMF3MF3_PointSeededRegions
    
    CellSeededRegions = _itkConnectedRegionsMeshFilterPython.itkConnectedRegionsMeshFilterMF3MF3_CellSeededRegions
    
    SpecifiedRegions = _itkConnectedRegionsMeshFilterPython.itkConnectedRegionsMeshFilterMF3MF3_SpecifiedRegions
    
    LargestRegion = _itkConnectedRegionsMeshFilterPython.itkConnectedRegionsMeshFilterMF3MF3_LargestRegion
    
    AllRegions = _itkConnectedRegionsMeshFilterPython.itkConnectedRegionsMeshFilterMF3MF3_AllRegions
    
    ClosestPointRegion = _itkConnectedRegionsMeshFilterPython.itkConnectedRegionsMeshFilterMF3MF3_ClosestPointRegion
    

    def SetExtractionMode(self, _arg):
        r"""
        SetExtractionMode(self, _arg)

        Parameters
        ----------
        _arg: int

        """
        return _itkConnectedRegionsMeshFilterPython.itkConnectedRegionsMeshFilterMF3MF3_SetExtractionMode(self, _arg)

    def GetExtractionMode(self):
        r"""GetExtractionMode(self) -> int"""
        return _itkConnectedRegionsMeshFilterPython.itkConnectedRegionsMeshFilterMF3MF3_GetExtractionMode(self)

    def SetExtractionModeToPointSeededRegions(self):
        r"""SetExtractionModeToPointSeededRegions(self)"""
        return _itkConnectedRegionsMeshFilterPython.itkConnectedRegionsMeshFilterMF3MF3_SetExtractionModeToPointSeededRegions(self)

    def SetExtractionModeToCellSeededRegions(self):
        r"""SetExtractionModeToCellSeededRegions(self)"""
        return _itkConnectedRegionsMeshFilterPython.itkConnectedRegionsMeshFilterMF3MF3_SetExtractionModeToCellSeededRegions(self)

    def SetExtractionModeToSpecifiedRegions(self):
        r"""SetExtractionModeToSpecifiedRegions(self)"""
        return _itkConnectedRegionsMeshFilterPython.itkConnectedRegionsMeshFilterMF3MF3_SetExtractionModeToSpecifiedRegions(self)

    def SetExtractionModeToLargestRegion(self):
        r"""SetExtractionModeToLargestRegion(self)"""
        return _itkConnectedRegionsMeshFilterPython.itkConnectedRegionsMeshFilterMF3MF3_SetExtractionModeToLargestRegion(self)

    def SetExtractionModeToAllRegions(self):
        r"""SetExtractionModeToAllRegions(self)"""
        return _itkConnectedRegionsMeshFilterPython.itkConnectedRegionsMeshFilterMF3MF3_SetExtractionModeToAllRegions(self)

    def SetExtractionModeToClosestPointRegion(self):
        r"""SetExtractionModeToClosestPointRegion(self)"""
        return _itkConnectedRegionsMeshFilterPython.itkConnectedRegionsMeshFilterMF3MF3_SetExtractionModeToClosestPointRegion(self)

    def InitializeSeedList(self):
        r"""InitializeSeedList(self)"""
        return _itkConnectedRegionsMeshFilterPython.itkConnectedRegionsMeshFilterMF3MF3_InitializeSeedList(self)

    def AddSeed(self, id):
        r"""
        AddSeed(self, id)

        Parameters
        ----------
        id: unsigned long

        """
        return _itkConnectedRegionsMeshFilterPython.itkConnectedRegionsMeshFilterMF3MF3_AddSeed(self, id)

    def DeleteSeed(self, id):
        r"""
        DeleteSeed(self, id)

        Parameters
        ----------
        id: unsigned long

        """
        return _itkConnectedRegionsMeshFilterPython.itkConnectedRegionsMeshFilterMF3MF3_DeleteSeed(self, id)

    def InitializeSpecifiedRegionList(self):
        r"""InitializeSpecifiedRegionList(self)"""
        return _itkConnectedRegionsMeshFilterPython.itkConnectedRegionsMeshFilterMF3MF3_InitializeSpecifiedRegionList(self)

    def AddSpecifiedRegion(self, id):
        r"""
        AddSpecifiedRegion(self, id)

        Parameters
        ----------
        id: unsigned long

        """
        return _itkConnectedRegionsMeshFilterPython.itkConnectedRegionsMeshFilterMF3MF3_AddSpecifiedRegion(self, id)

    def DeleteSpecifiedRegion(self, id):
        r"""
        DeleteSpecifiedRegion(self, id)

        Parameters
        ----------
        id: unsigned long

        """
        return _itkConnectedRegionsMeshFilterPython.itkConnectedRegionsMeshFilterMF3MF3_DeleteSpecifiedRegion(self, id)

    def SetClosestPoint(self, p):
        r"""
        SetClosestPoint(self, p)

        Parameters
        ----------
        p: itkPointF3 &

        """
        return _itkConnectedRegionsMeshFilterPython.itkConnectedRegionsMeshFilterMF3MF3_SetClosestPoint(self, p)

    def GetClosestPoint(self, arg0):
        r"""
        GetClosestPoint(self, arg0) -> itkPointF3

        Parameters
        ----------
        arg0: itkPointF3 &

        """
        return _itkConnectedRegionsMeshFilterPython.itkConnectedRegionsMeshFilterMF3MF3_GetClosestPoint(self, arg0)

    def GetNumberOfExtractedRegions(self):
        r"""GetNumberOfExtractedRegions(self) -> unsigned long"""
        return _itkConnectedRegionsMeshFilterPython.itkConnectedRegionsMeshFilterMF3MF3_GetNumberOfExtractedRegions(self)
    __swig_destroy__ = _itkConnectedRegionsMeshFilterPython.delete_itkConnectedRegionsMeshFilterMF3MF3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkConnectedRegionsMeshFilterMF3MF3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkConnectedRegionsMeshFilterPython.itkConnectedRegionsMeshFilterMF3MF3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkConnectedRegionsMeshFilterMF3MF3

        Create a new object of the class itkConnectedRegionsMeshFilterMF3MF3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkConnectedRegionsMeshFilterMF3MF3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkConnectedRegionsMeshFilterMF3MF3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkConnectedRegionsMeshFilterMF3MF3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkConnectedRegionsMeshFilterMF3MF3 in _itkConnectedRegionsMeshFilterPython:
_itkConnectedRegionsMeshFilterPython.itkConnectedRegionsMeshFilterMF3MF3_swigregister(itkConnectedRegionsMeshFilterMF3MF3)

from itk.support import helpers
import itk.support.types as itkt
from typing import Sequence, Tuple, Union

@helpers.accept_array_like_xarray_torch
def connected_regions_mesh_filter(*args: itkt.Mesh,  extraction_mode: int=..., closest_point: Sequence[float]=..., output: itkt.Mesh=...,**kwargs)-> itkt.MeshSourceReturn:
    """Functional interface for ConnectedRegionsMeshFilter"""
    import itk

    kwarg_typehints = { 'extraction_mode':extraction_mode,'closest_point':closest_point,'output':output }
    specified_kwarg_typehints = { k:v for (k,v) in kwarg_typehints.items() if kwarg_typehints[k] is not ... }
    kwargs.update(specified_kwarg_typehints)


    instance = itk.ConnectedRegionsMeshFilter.New(*args, **kwargs)

    return instance.__internal_call__()

def connected_regions_mesh_filter_init_docstring():
    import itk
    from itk.support import template_class

    filter_class = itk.ITKMesh.ConnectedRegionsMeshFilter
    connected_regions_mesh_filter.process_object = filter_class
    is_template = isinstance(filter_class, template_class.itkTemplate)
    if is_template:
        filter_object = filter_class.values()[0]
    else:
        filter_object = filter_class

    connected_regions_mesh_filter.__doc__ = filter_object.__doc__



